This takes the distance matrix, which is one row/col per clone, and joined this with the seuratObj in order to make a larger matrix with one column/cell

ExpandDistancesToMatchSeuratObj(seuratObj, chains)

Arguments

seuratObj

The seurat object

chains

A single chain or vector of the joint chains to use