ApplyClusteringResultsToSeurat.RdThis takes a seuratObject with TCR clustering results calculated, and then joins the TCR family IDs from this object to the target object, where this join is performed using the CDR3, V and J data.
ApplyClusteringResultsToSeurat(sourceSeuratObj, targetSeuratObj)