Can be used to set the python executable used by tcrClustR
GetDistanceMatrix(seuratObj_TCR, chains, cdr3Only = FALSE)
Arguments
- seuratObj_TCR
The seurat object, created by CalculateTcrDistances
- chains
The chain or chains to return (e.g., TRA or c('TRG', 'TRD'))
- cdr3Only
If true, it will return the distances calculated on CDR3 alone. The default uses distances based on CDR3+V/J