VisualizeTcrDistances.Rd
This takes the seuratObject and prints several visualizations for each distance matrix and/or clustering
VisualizeTcrDistances(seuratObj, showDimplotLegend = FALSE)
The seurat object
Boolean controlling whether to show the legend on the DimPlot